@@ -11,14 +11,23 @@ from sortedcontainers import SortedSet
 
 from bakplane.bakplane_pb2 import ErrorEntry
 from bakplane.ingestion.landing_zone import LandingZoneFactory
-from .models import Asset, Entity, Relationship, IngestionSessionContext, Error, Descriptor
+from .models import (
+    Asset,
+    Entity,
+    Relationship,
+    IngestionSessionContext,
+    Error,
+    Descriptor,
+)
 
 PARTITION_NUM = os.cpu_count()
-KEY_SEPARATOR = '::'
+KEY_SEPARATOR = "::"
 
 
-def reduce_pair(p1: typing.Tuple[datetime.datetime, datetime.datetime],
-                p2: typing.Tuple[datetime.datetime, datetime.datetime]):
+def reduce_pair(
+    p1: typing.Tuple[datetime.datetime, datetime.datetime],
+    p2: typing.Tuple[datetime.datetime, datetime.datetime],
+):
     a, b = p1
     c, d = p2
 
@@ -28,7 +37,7 @@ def reduce_pair(p1: typing.Tuple[datetime.datetime, datetime.datetime],
         elif b > d:
             return (a, b), None
         else:
-            raise RuntimeError('Not allowed')
+            raise RuntimeError("Not allowed")
     elif a < c:
         if b == d:
             return (a, b), None
@@ -44,7 +53,7 @@ def reduce_pair(p1: typing.Tuple[datetime.datetime, datetime.datetime],
 
 def reduce_intervals(s: SortedSet) -> SortedSet:
     if not s:
-        raise RuntimeError('Input cannot be none.')
+        raise RuntimeError("Input cannot be none.")
 
     if len(s) == 1:
         return s
@@ -102,8 +111,14 @@ class RelationshipReduceMap:
         self.append(r)
 
     def append(self, r: Relationship):
-        if r.source_identity_uid != self.source_identity_uid or r.target_identity_uid != self.target_identity_uid or r.relationship_type != self.relationship_type:
-            raise RuntimeError('Invalid relationship identity for this reducer.')
+        if (
+            r.source_identity_uid != self.source_identity_uid
+            or r.target_identity_uid != self.target_identity_uid
+            or r.relationship_type != self.relationship_type
+        ):
+            raise RuntimeError(
+                "Invalid relationship identity for this reducer."
+            )
 
         for e in r.effective_dating:
             self.effective_dating.add((e[0], e[1]))
@@ -120,7 +135,7 @@ class RelationshipReduceMap:
             relationship_type=self.relationship_type,
             source_identity_uid=self.source_identity_uid,
             target_identity_uid=self.target_identity_uid,
-            effective_dating=reduced_intervals
+            effective_dating=reduced_intervals,
         )
 
 
@@ -133,7 +148,9 @@ class EntityReduceMap:
 
     def append(self, entity: Entity):
         if entity.identity.uid != self.identity.uid:
-            raise RuntimeError(f'Entity mismatch: expected entity with identity `{entity.identity.uid}`.')
+            raise RuntimeError(
+                f"Entity mismatch: expected entity with identity `{entity.identity.uid}`."
+            )
 
         for d in entity.descriptors:
             self.append_descriptor(d)
@@ -160,22 +177,35 @@ class EntityReduceMap:
 
                 effective_dating.append((start, end))
 
-            descriptors.append(Descriptor(
-                attribute=attr,
-                value=val,
-                effective_dating=effective_dating
-            ))
+            descriptors.append(
+                Descriptor(
+                    attribute=attr,
+                    value=val,
+                    effective_dating=effective_dating,
+                )
+            )
 
         self.values = None
         return Entity(identity=self.identity, descriptors=descriptors)
 
 
 class DefaultEmitter(Emitter):
-    def __init__(self, context: IngestionSessionContext, asset_num_sharding=8, entities_num_sharding=8,
-                 rels_num_sharding=8, csv_separator: str = '|', null_value: str = 'NULL'):
+    def __init__(
+        self,
+        context: IngestionSessionContext,
+        asset_num_sharding=8,
+        entities_num_sharding=8,
+        rels_num_sharding=8,
+        csv_separator: str = "|",
+        null_value: str = "NULL",
+    ):
 
-        if asset_num_sharding < 1 or entities_num_sharding < 1 or rels_num_sharding < 1:
-            raise RuntimeError('Invalid requested number of shards.')
+        if (
+            asset_num_sharding < 1
+            or entities_num_sharding < 1
+            or rels_num_sharding < 1
+        ):
+            raise RuntimeError("Invalid requested number of shards.")
 
         self.ctx = context
         self.fd_map: typing.Dict[str, IO] = {}
@@ -207,11 +237,11 @@ class DefaultEmitter(Emitter):
         self.null_value = null_value
 
     def __get_entities_fd(self, entity: Entity) -> IO:
-        key = 'entities'
+        key = "entities"
 
         if self.entities_num_sharding > 1:
             shard = entity.identity.uid % self.entities_num_sharding
-            key += f'___{shard}_of_{self.entities_num_sharding}_'
+            key += f"___{shard}_of_{self.entities_num_sharding}_"
 
         if key not in self.fd_map:
             self.fd_map[key] = tempfile.NamedTemporaryFile(
@@ -227,11 +257,11 @@ class DefaultEmitter(Emitter):
         return self.fd_map["errors"]
 
     def __get_relationships_fd(self, relationship: Relationship) -> IO:
-        key = 'relationships'
+        key = "relationships"
 
         if self.rels_num_sharding > 1:
             shard = relationship.source_identity_uid % self.rels_num_sharding
-            key += f'___{shard}_of_{self.rels_num_sharding}_'
+            key += f"___{shard}_of_{self.rels_num_sharding}_"
 
         if key not in self.fd_map:
             self.fd_map[key] = tempfile.NamedTemporaryFile(
@@ -244,7 +274,7 @@ class DefaultEmitter(Emitter):
 
         if self.asset_num_sharding > 1:
             shard = asset.payload_hash % self.asset_num_sharding
-            key += f'___{shard}_of_{self.asset_num_sharding}_'
+            key += f"___{shard}_of_{self.asset_num_sharding}_"
 
         if key not in self.fd_map:
             self.fd_map[key] = tempfile.NamedTemporaryFile(
@@ -267,13 +297,18 @@ class DefaultEmitter(Emitter):
 
     def __write_relationship(self, relationship: Relationship):
         if relationship.identity not in self.rel_map:
-            self.rel_map[relationship.identity] = RelationshipReduceMap(relationship)
+            self.rel_map[relationship.identity] = RelationshipReduceMap(
+                relationship
+            )
         else:
             self.rel_map[relationship.identity].append(relationship)
 
     def __write_asset(self, asset: Asset):
         f = self.__get_assets_fd(asset)
-        f.write(asset.to_csv_entry(self.ctx, self.csv_separator, self.null_value) + "\n")
+        f.write(
+            asset.to_csv_entry(self.ctx, self.csv_separator, self.null_value)
+            + "\n"
+        )
 
     def emit_entities(self, entities: typing.List[Entity]):
         if entities is None or len(entities) <= 0:
@@ -331,11 +366,20 @@ class DefaultEmitter(Emitter):
             v.close()
 
             if k.startswith("entities"):
-                self.entities_lz.upload(v.name, self.ctx.entities_output_location, ".proto.gz", prefix="entities")
+                self.entities_lz.upload(
+                    v.name,
+                    self.ctx.entities_output_location,
+                    ".proto.gz",
+                    prefix="entities",
+                )
 
             elif k.startswith("relationships"):
-                self.relationships_lz.upload(v.name, self.ctx.relationships_output_location, ".proto.gz",
-                                             prefix='relationships')
+                self.relationships_lz.upload(
+                    v.name,
+                    self.ctx.relationships_output_location,
+                    ".proto.gz",
+                    prefix="relationships",
+                )
 
             elif k == "errors":
                 self.errors_lz.upload(
@@ -347,5 +391,9 @@ class DefaultEmitter(Emitter):
             else:
                 asset_code = k
                 if self.asset_num_sharding > 1:
-                    asset_code = asset_code.split('___')[0]
-                    self.assets_lz.upload(v.name, self.ctx.assets_output_location + asset_code + "/", ".csv.gz")
+                    asset_code = asset_code.split("___")[0]
+                    self.assets_lz.upload(
+                        v.name,
+                        self.ctx.assets_output_location + asset_code + "/",
+                        ".csv.gz",
+                    )
