@@ -29,17 +29,17 @@ class IngestionSessionContext:
         return IngestionSessionContext(
             ingestion_session_id=int(os.getenv("INGESTION_SESSION_ID", 0)),
             entities_output_location=os.getenv(
-                "ENTITIES_OUTPUT_LOCATION", f'file://{tempfile.mkdtemp()}/'
+                "ENTITIES_OUTPUT_LOCATION", f"file://{tempfile.mkdtemp()}/"
             ),
             assets_output_location=os.getenv(
-                "ASSETS_OUTPUT_LOCATION", f'file://{tempfile.mkdtemp()}/'
+                "ASSETS_OUTPUT_LOCATION", f"file://{tempfile.mkdtemp()}/"
             ),
             errors_output_location=os.getenv(
-                "ERRORS_OUTPUT_LOCATION", f'file://{tempfile.mkdtemp()}/'
+                "ERRORS_OUTPUT_LOCATION", f"file://{tempfile.mkdtemp()}/"
             ),
             relationships_output_location=os.getenv(
                 "RELATIONSHIPS_OUTPUT_LOCATION",
-                f'file://{tempfile.mkdtemp()}/'
+                f"file://{tempfile.mkdtemp()}/",
             ),
         )
 
@@ -95,7 +95,9 @@ class Asset:
     def payload_hash(self):
         return self.calculate_hash(self.payload_hash_fields)
 
-    def to_csv_entry(self, ctx: IngestionSessionContext, csv_separator: str, null_value: str):
+    def to_csv_entry(
+        self, ctx: IngestionSessionContext, csv_separator: str, null_value: str
+    ):
         parts = []
 
         sorted_retrieved_by = sorted(self.retrieved_by.keys())
@@ -149,8 +151,16 @@ class Asset:
         parts.append(str(self.payload_hash))
 
         return csv_separator.join(
-            [x.strip().replace(csv_separator, "").replace("\n", "").replace("\r", "") if x is not None else null_value
-             for x in parts])
+            [
+                x.strip()
+                .replace(csv_separator, "")
+                .replace("\n", "")
+                .replace("\r", "")
+                if x is not None
+                else null_value
+                for x in parts
+            ]
+        )
 
 
 @dataclass
@@ -181,8 +191,12 @@ class Identity:
 class Descriptor:
     attribute: str
     value: str
-    effective_dating: typing.List[typing.Tuple[datetime.datetime, datetime.datetime]]
-    knowledge_dating: typing.List[typing.Tuple[datetime.datetime, datetime.datetime]] = None
+    effective_dating: typing.List[
+        typing.Tuple[datetime.datetime, datetime.datetime]
+    ]
+    knowledge_dating: typing.List[
+        typing.Tuple[datetime.datetime, datetime.datetime]
+    ] = None
 
     def to_proto(self) -> PDescriptor:
         return PDescriptor(
@@ -192,7 +206,8 @@ class Descriptor:
                 TimestampRange(
                     start_dt=to_proto_timestamp(x[0]),
                     end_dt=to_proto_timestamp(x[1]),
-                ) for x in self.effective_dating
+                )
+                for x in self.effective_dating
             ],
         )
 
@@ -214,11 +229,17 @@ class Relationship:
     source_identity_uid: int
     target_identity_uid: int
     relationship_type: str
-    effective_dating: typing.List[typing.Tuple[datetime.datetime, datetime.datetime]]
+    effective_dating: typing.List[
+        typing.Tuple[datetime.datetime, datetime.datetime]
+    ]
 
     @property
     def identity(self):
-        return hash(self.source_identity_uid) + hash(self.target_identity_uid) + hash(self.relationship_type)
+        return (
+            hash(self.source_identity_uid)
+            + hash(self.target_identity_uid)
+            + hash(self.relationship_type)
+        )
 
     def to_proto(self) -> RelationshipEntry:
         return RelationshipEntry(
@@ -229,7 +250,8 @@ class Relationship:
                 TimestampRange(
                     start_dt=to_proto_timestamp(x[0]),
                     end_dt=to_proto_timestamp(x[1]),
-                ) for x in self.effective_dating
+                )
+                for x in self.effective_dating
             ],
         )
 
